@@ -49,7 +49,13 @@ where
     chain!(
         jsx_src(development, cm.clone()),
         jsx_self(development),
-        refresh(development, refresh_options, cm.clone(), comments.clone()),
+        refresh(
+            development,
+            refresh_options,
+            cm.clone(),
+            comments.clone(),
+            top_level_mark
+        ),
         jsx(cm, comments.clone(), options, top_level_mark),
         display_name(),
         pure_annotations(comments),
